@@ -1,7 +1,7 @@
 
 from app import flask_app
 from flask import render_template
-# from app import helpers
+from app import helpers
 
 flask_app.config['UPLOADS'] = '/static/img/'
 @flask_app.route('/')
